Public Sessions — Admin

# Public Sessions Admin

← Computer (Admin)

Code | Name | Description | Instructions | Lock | Messages | Last Active | Created | Actions
--- | --- | --- | --- | --- | --- | --- | --- | ---

No public sessions found.

## New Session

Session Name Description Instructions
Lock settings (users cannot change name/description/instructions)

## Bulk Create Sessions

Paste JSON array. Each item: `{"session_name", "session_description", "session_instructions"}`.
All will be created with settings locked. Or enter a count to create identical sessions.
Count (identical sessions) Shared Name Prefix Shared Instructions — OR paste JSON array —